<?php

namespace Waggybytes\SimplyRemindMe\Library\Localisation;

use Carbon\Carbon;
use Waggybytes\SimplyRemindMe\Library\Models\User;

class DateTimeHandler
{
    /**
     * Starts with 'now' in UTC.
     * @return DateTimeHandler
     */
    public static function now(?User $user = null)
    {
        $instance = new DateTimeHandler();
        $instance->current = Carbon::now(is_null($user) ? 'UTC' : $user->timezone->identifier);

        return $instance;
    }

    /**
     * Starts processing an input string.
     * @param $input
     * @return DateTimeHandlerParser
     */
    public static function parse($input)
    {
        $instance = new DateTimeHandler();
        $instance->parseInput = $input;
        $parser = new DateTimeHandlerParser($instance);

        return $parser;
    }

    public static function today(?User $user = null)
    {
        $instance = new DateTimeHandler();
        $instance->current = Carbon::today(is_null($user) ? 'UTC' : $user->timezone->identifier);

        return $instance;
    }

    /**
     * Starts with a given Carbon instance that must be in UTC.
     * @param Carbon $carbon
     * @return DateTimeHandler
     */
    public static function using(Carbon $carbon)
    {
        $timezoneName = $carbon->getTimezone()->getName();
        if ($timezoneName != 'UTC')
        {
            throw new \Exception(sprintf('Unexpected timezone \'%s\', expected UTC', $timezoneName));
        }

        $instance = new DateTimeHandler();
        $instance->current = $carbon;

        return $instance;
    }

    /**
     * @var Carbon
     */
    private $current;

    /**
     * @var string
     */
    private $parseInput;

    private function __construct()
    {
    }

    /**
     * Switches a timezone between UTC and a user's timezone.
     * @return DateTimeHandlerConverter
     */
    public function convertTimezone()
    {
        return new DateTimeHandlerConverter($this);
    }

    public function current(): Carbon
    {
        return $this->current;
    }

    /**
     * Formats the result of the current value.
     * @return DateTimeHandlerFormatter
     */
    public function format(): DateTimeHandlerFormatter
    {
        return new DateTimeHandlerFormatter($this);
    }

    public function parseInput(): string
    {
        return $this->parseInput;
    }

    public function overrideCurrent(Carbon $current)
    {
        $this->current = $current;
    }
}