<?php

namespace Waggybytes\SimplyRemindMe\Library\Localisation;

use Carbon\Carbon;
    use Waggybytes\SimplyRemindMe\Library\Models\User;

class DateTimeHandlerFormatter
{
    const API_DATE_FORMAT = 'Y-m-d\TH:i:s';

    public function __construct(private DateTimeHandler $converter)
    {
    }

    public function toAPI()
    {
        return $this->formatCurrent(self::API_DATE_FORMAT);
    }

    public function toCustom($formatString): string
    {
        return $this->formatCurrent($formatString);
    }

    public function toISO()
    {
        return $this->formatCurrent('c');
    }

    public function toMariaDB()
    {
        return $this->formatCurrent('Y-m-d H:i:s');
    }

    /**
     * Returns an array with 2 keys containing the date and time in the user's specific format.
     * <prefix>_fmt_d
     * <prefix>_fmt_t
     * @return mixed
     */
    public function toUser(User $user, $prefix, $dateFormat = 'long', $timeFormat = 'long', $excludeTimeIfZero = false): mixed
    {
        $result = [
            sprintf('%s_date', $prefix) => $this->toUserDate($user, $dateFormat)
        ];

        $currentDateTime = $this->converter->current();
        if (
            !$excludeTimeIfZero ||
            ($excludeTimeIfZero && $currentDateTime->hour != 0 || $currentDateTime->minute != 0)
        )
        {
            $result[sprintf('%s_time', $prefix)] = $this->toUserTime($user, $timeFormat);
        }

        return $result;
    }

    public function toUserDate(User $user, $dateFormat = 'long'): string
    {
        $dateFormat .= 'Date';

        return $this->formatCurrent($user->currentConfiguration()->$dateFormat->php_date_format);
    }

    public function toUserTime(User $user, $timeFormat = 'long'): string
    {
        $timeFormat .= 'Time';

        return $this->formatCurrent($user->currentConfiguration()->$timeFormat->php_date_format);
    }

    private function formatCurrent($formatString): string
    {
        return $this->converter->current()->format($formatString);
    }
}