<?php

namespace Waggybytes\SimplyRemindMe\Library\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class UserAvatar extends Model
{
    use HasFactory;

    const SOURCE_CUSTOM = 'custom';
    const SOURCE_GRAVATAR = 'gravatar';
    const SOURCE_NONE = 'empty';
    const SOURCE_SOCIAL = 'social';

    public static function make(User $user)
    {
        $avatar = new UserAvatar();
        $avatar->user_id = $user->id;
        $avatar->save();

        return $avatar;
    }

    protected $casts = [
        'is_gravatar_allowed' => 'boolean',
        'is_social_avatar_allowed' => 'boolean'
    ];

    protected $fillable = [
        'is_gravatar_allowed',
        'is_social_avatar_allowed'
    ];

    public function source()
    {
        $avatarSource = self::SOURCE_NONE;

        if (!empty($this->custom_avatar))
        {
            $avatarSource = self::SOURCE_CUSTOM;
        }
        else if ($this->is_social_avatar_allowed && !empty($this->social_avatar_url))
        {
            $avatarSource = self::SOURCE_SOCIAL;
        }
        else if ($this->is_gravatar_allowed)
        {
            $avatarSource = self::SOURCE_GRAVATAR;
        }

        return $avatarSource;
    }

    public static function thumbnailSizes()
    {
        return [
            ['w' => 32, 'h' => 32],
            ['w' => 96, 'h' => 96]
        ];
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }
}
