<?php

namespace Waggybytes\SimplyRemindMe\Library\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

/**
 * @property integer $long_date_date_format_id
 * @property integer $short_date_date_format_id
 * @property integer $long_time_date_format_id
 * @property integer $short_time_date_format_id
 * @property DateFormat $longDate
 * @property DateFormat $longTime
 * @property DateFormat $shortDate
 * @property DateFormat $shortTime
 */
class UserConfiguration extends Model
{
    use HasFactory;

    public static function make(User $user)
    {
        $config = new UserConfiguration();
        $config->user_id = $user->id;

        // Set default values
        $config->long_date_date_format_id = DateFormat::defaultDateFormat('long_date')->id;
        $config->long_time_date_format_id = DateFormat::defaultDateFormat('long_time')->id;
        $config->short_date_date_format_id = DateFormat::defaultDateFormat('short_date')->id;
        $config->short_time_date_format_id = DateFormat::defaultDateFormat('short_time')->id;
        $config->save();

        return $config;
    }

    protected $fillable = [
        'long_date_date_format_id',
        'long_time_date_format_id',
        'short_date_date_format_id',
        'short_time_date_format_id'
    ];

    public function longDate()
    {
        return $this->belongsTo(DateFormat::class, 'long_date_date_format_id');
    }

    public function longTime()
    {
        return $this->belongsTo(DateFormat::class, 'long_time_date_format_id');
    }

    public function shortDate()
    {
        return $this->belongsTo(DateFormat::class, 'short_date_date_format_id');
    }

    public function shortTime()
    {
        return $this->belongsTo(DateFormat::class, 'short_time_date_format_id');
    }
}
